from abc import ABCMeta, abstractmethod

import networkx as nx


class GraphPersistence(metaclass=ABCMeta):
    @abstractmethod
    def load(self) -> nx.Graph:
        pass

    @abstractmethod
    def save(self, g: nx.Graph) -> None:
        pass



from matchescu.similarity._matcher import Matcher
from matchescu.similarity._persistence import GraphPersistence
from matchescu.similarity._reference_graph import ReferenceGraph


__all__ = ["GraphPersistence", "Matcher", "ReferenceGraph"]
